# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v3.22.0~cdb0ab7',
    built_at='2023-04-04 15:01:37Z',
    sha='cdb0ab7e7db1155b40cfd4d3bca29a7040c3ec2b',
    branch='HEAD',
    tag='v3.22.0',
)
